/*
PRICE was written by Graham Ruby.
This file is part of PRICE.

PRICE is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PRICE is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PRICE.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef SCOREDSEQFLIP_CPP
#define SCOREDSEQFLIP_CPP

#include "ScoredSeqFlip.h"
#include "ScoredSeqShallow.h"


long ScoredSeqFlip::_readCount = 0;

ScoredSeqFlip::ScoredSeqFlip(){}; //default constructor

ScoredSeqFlip::ScoredSeqFlip(ScoredSeq* innerSeq, char sense) :
  _sense(sense),
  _innerSeq(innerSeq){
  //_bufferSeq = 0;
  //_readCount++;
  //OK();
}

ScoredSeqFlip::~ScoredSeqFlip(){
  //unbuffer();
  //_readCount--;
}


void ScoredSeqFlip::OK(){
  if (_innerSeq == 0){
    throw AssemblyException::LogicError("inner seq should not be null in SSNormalized");
  }
  _innerSeq->getSeq('+'); // call a method
}


float ScoredSeqFlip::scoreAtPosition(long position, char sense) {
  //OK();
  //if (_bufferSeq != 0){ return _bufferSeq->scoreAtPosition(position,sense); }
  //else if (sense == _sense){ return _innerSeq->scoreAtPosition(position,'+'); }
  if (sense == _sense){ return _innerSeq->scoreAtPosition(position,'+'); }
  else { return _innerSeq->scoreAtPosition(position,'-'); }
}

float ScoredSeqFlip::linkAfterPosition(long position, char sense) {
  //OK();
  //if (_bufferSeq != 0){ return _bufferSeq->linkAfterPosition(position,sense); }
  //else if (sense == _sense){ return _innerSeq->linkAfterPosition(position,'+'); }
  if (sense == _sense){ return _innerSeq->linkAfterPosition(position,'+'); }
  else { return _innerSeq->linkAfterPosition(position,'-'); }
}


char ScoredSeqFlip::nucAtPosition(long position, char sense) {
  //OK();
  //if (_bufferSeq != 0){ return _bufferSeq->nucAtPosition(position,sense); }
  //else if (sense == _sense){ return _innerSeq->nucAtPosition(position,'+'); }
  if (sense == _sense){ return _innerSeq->nucAtPosition(position,'+'); }
  else { return _innerSeq->nucAtPosition(position,'-'); }
}

string ScoredSeqFlip::getSeq(char sense) {
  //OK();
  //if (_bufferSeq != 0){ return _bufferSeq->getSeq(sense); }
  //else if (sense == _sense){ return _innerSeq->getSeq('+'); }
  if (sense == _sense){ return _innerSeq->getSeq('+'); }
  else { return _innerSeq->getSeq('-'); }
}
string ScoredSeqFlip::getSubseq(long position, long length, char sense){
  //OK();
  //if (_bufferSeq != 0){ return _bufferSeq->getSubseq(position,length,sense); }
  //else if (sense == _sense){ return _innerSeq->getSubseq(position,length,'+'); }
  if (sense == _sense){ return _innerSeq->getSubseq(position,length,'+'); }
  else { return _innerSeq->getSubseq(position,length,'-'); }
}


char ScoredSeqFlip::getSense() { return _sense; }

long ScoredSeqFlip::size() {
  //OK();
  //if (_bufferSeq != 0){ return _bufferSeq->size(); }
  //else { return _innerSeq->size(); }
  return _innerSeq->size();
}

void ScoredSeqFlip::buffer(){
  //OK();
  //if (_bufferSeq == 0){ _bufferSeq = new ScoredSeqShallow(this,'+'); }
}
void ScoredSeqFlip::unbuffer(){
  //OK();
  //delete _bufferSeq;
  //_bufferSeq = 0;
}
void ScoredSeqFlip::bottomBuffer(){
  //OK();
  _innerSeq->bottomBuffer();
}


bool ScoredSeqFlip::hasPairedEnd() {
  return false;
}

ScoredSeq * ScoredSeqFlip::getPairedEnd() {
  throw AssemblyException::CallingError("Paired end issues still need to be worked out for ScoredSeqFlip");
}
ScoredSeq * ScoredSeqFlip::getTempPairedEnd() {
  throw AssemblyException::CallingError("Paired end issues still need to be worked out for ScoredSeqFlip");
}

ScoredSeq * ScoredSeqFlip::shallowCopy(){
  //OK();
  return new ScoredSeqShallow(this,'+');
}
ScoredSeq * ScoredSeqFlip::flipCopy(){
  //OK();
  return new ScoredSeqShallow(this,'-');
}

bool ScoredSeqFlip::isNested(){ return true; }
ScoredSeq* ScoredSeqFlip::getNested(){ return _innerSeq; }
void ScoredSeqFlip::deepDelete(){
  deepUnbuffer();
  _innerSeq->deepDelete();
  delete this;
}
void ScoredSeqFlip::deepUnbuffer(){
  unbuffer();
  _innerSeq->deepUnbuffer();
}

#endif
