/*
PRICE was written by Graham Ruby.
This file is part of PRICE.

PRICE is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PRICE is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PRICE.  If not, see <http://www.gnu.org/licenses/>.
*/

/*
 * This is a wrapper for a ScoredSeq that just flips the sequence
 * over.  It is just supposed to speed up some operations.  It can
 * also wrap a sequence without flipping it.
 */

#ifndef SCOREDSEQFLIP_H
#define SCOREDSEQFLIP_H

#include "ScoredSeqNested.h"
#include "AssemblyException.h"
#include "AssemblyException.h"

class ScoredSeqFlip : public ScoredSeqNested {
 public:
  ScoredSeqFlip(); //default constructor
  ScoredSeqFlip(ScoredSeq* innerSeq, char sense);
  ~ScoredSeqFlip();

  static long _readCount;

  /* see parent abstract class ScoredSeq */
  float scoreAtPosition(long position, char sense);
  float linkAfterPosition(long position, char sense);
  char nucAtPosition(long position, char sense);
  string getSeq(char sense);
  string getSubseq(long position, long length, char sense);
  void buffer();
  void unbuffer();
  void bottomBuffer();
  long size();
  bool hasPairedEnd();
  ScoredSeq * getPairedEnd();
  ScoredSeq * getTempPairedEnd();
  ScoredSeq * shallowCopy();
  ScoredSeq * flipCopy();
  bool isNested();
  /* see parent abstract class ScoredSeqNested */
  ScoredSeq* getNested();
  void deepDelete();
  void deepUnbuffer();

  // class-specific
  void addCount();
  void addCounts(long counts);
  long getCount();
  void OK();
  char getSense();

 private:
  char _sense;
  ScoredSeq* _innerSeq;
  //ScoredSeq* _bufferSeq;

};

#endif
